/*
    uart programmer for Cypress PSoC.
    CYACD file loader.
    Copyright (C) 2015  Michael Stickel (michael@cubic.org)

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef DEFINED_CYPRESS_CYACD_FILE
#define DEFINED_CYPRESS_CYACD_FILE

#include <vector>

/*
 * One row of a cyacd file.
 */
struct FlashRow
{
    int flashArrayId;
    int flashRowNumber;
    int byteCount;
    unsigned char checksum;
    unsigned char data[256];
};

/*
 * The content of one cyacd file.
 */
struct CyacdFileContent
{
    unsigned long siliconId;
    unsigned char siliconRev;
    int checksumType;
    int firstRowToProgram;
    int lastRowToProgram;
    std::vector<FlashRow> rows;
};


/*
 * Load the data of a Cypress cyacd file and fill it into <_data>.
 */
int PsocFileLoadCyacd(const char * _filename, CyacdFileContent & _data);

/*
 * Dump the data from the cyacd file content on standard output.
 */
void PsocFileDumpContents(const CyacdFileContent & _data, const int _dumlevel);

#endif //  DEFINED_CYPRESS_CYACD_FILE
